@@ -29,6 +29,7 @@ from mypy_boto3_datasync.type_defs import (
     CreateLocationEfsResponseTypeDef,
     CreateLocationFsxWindowsResponseTypeDef,
     CreateLocationNfsResponseTypeDef,
+    CreateLocationObjectStorageResponseTypeDef,
     CreateLocationS3ResponseTypeDef,
     CreateLocationSmbResponseTypeDef,
     CreateTaskResponseTypeDef,
@@ -36,6 +37,7 @@ from mypy_boto3_datasync.type_defs import (
     DescribeLocationEfsResponseTypeDef,
     DescribeLocationFsxWindowsResponseTypeDef,
     DescribeLocationNfsResponseTypeDef,
+    DescribeLocationObjectStorageResponseTypeDef,
     DescribeLocationS3ResponseTypeDef,
     DescribeLocationSmbResponseTypeDef,
     DescribeTaskExecutionResponseTypeDef,
@@ -47,6 +49,7 @@ from mypy_boto3_datasync.type_defs import (
     ListTagsForResourceResponseTypeDef,
     ListTaskExecutionsResponseTypeDef,
     ListTasksResponseTypeDef,
+    LocationFilterTypeDef,
     NfsMountOptionsTypeDef,
     OnPremConfigTypeDef,
     OptionsTypeDef,
@@ -54,6 +57,7 @@ from mypy_boto3_datasync.type_defs import (
     SmbMountOptionsTypeDef,
     StartTaskExecutionResponseTypeDef,
     TagListEntryTypeDef,
+    TaskFilterTypeDef,
     TaskScheduleTypeDef,
 )
 
@@ -74,19 +78,19 @@ class Exceptions:
 
 class DataSyncClient:
     """
-    [DataSync.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client)
+    [DataSync.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.can_paginate)
         """
 
     def cancel_task_execution(self, TaskExecutionArn: str) -> Dict[str, Any]:
         """
-        [Client.cancel_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Client.cancel_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         """
 
     def create_agent(
@@ -99,7 +103,7 @@ class DataSyncClient:
         SecurityGroupArns: List[str] = None,
     ) -> CreateAgentResponseTypeDef:
         """
-        [Client.create_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Client.create_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_agent)
         """
 
     def create_location_efs(
@@ -110,7 +114,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationEfsResponseTypeDef:
         """
-        [Client.create_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Client.create_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_efs)
         """
 
     def create_location_fsx_windows(
@@ -124,7 +128,7 @@ class DataSyncClient:
         Domain: str = None,
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
-        [Client.create_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Client.create_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         """
 
     def create_location_nfs(
@@ -136,7 +140,23 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationNfsResponseTypeDef:
         """
-        [Client.create_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Client.create_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        """
+
+    def create_location_object_storage(
+        self,
+        ServerHostname: str,
+        BucketName: str,
+        AgentArns: List[str],
+        ServerPort: int = None,
+        ServerProtocol: Literal["HTTPS", "HTTP"] = None,
+        Subdirectory: str = None,
+        AccessKey: str = None,
+        SecretKey: str = None,
+        Tags: List["TagListEntryTypeDef"] = None,
+    ) -> CreateLocationObjectStorageResponseTypeDef:
+        """
+        [Client.create_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         """
 
     def create_location_s3(
@@ -155,7 +175,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationS3ResponseTypeDef:
         """
-        [Client.create_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Client.create_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_s3)
         """
 
     def create_location_smb(
@@ -170,7 +190,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationSmbResponseTypeDef:
         """
-        [Client.create_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Client.create_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_location_smb)
         """
 
     def create_task(
@@ -185,66 +205,73 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateTaskResponseTypeDef:
         """
-        [Client.create_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.create_task)
+        [Client.create_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.create_task)
         """
 
     def delete_agent(self, AgentArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Client.delete_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.delete_agent)
         """
 
     def delete_location(self, LocationArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Client.delete_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.delete_location)
         """
 
     def delete_task(self, TaskArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Client.delete_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.delete_task)
         """
 
     def describe_agent(self, AgentArn: str) -> DescribeAgentResponseTypeDef:
         """
-        [Client.describe_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Client.describe_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_agent)
         """
 
     def describe_location_efs(self, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
         """
-        [Client.describe_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Client.describe_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         """
 
     def describe_location_fsx_windows(
         self, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
         """
-        [Client.describe_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Client.describe_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         """
 
     def describe_location_nfs(self, LocationArn: str) -> DescribeLocationNfsResponseTypeDef:
         """
-        [Client.describe_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Client.describe_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        """
+
+    def describe_location_object_storage(
+        self, LocationArn: str
+    ) -> DescribeLocationObjectStorageResponseTypeDef:
+        """
+        [Client.describe_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         """
 
     def describe_location_s3(self, LocationArn: str) -> DescribeLocationS3ResponseTypeDef:
         """
-        [Client.describe_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Client.describe_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         """
 
     def describe_location_smb(self, LocationArn: str) -> DescribeLocationSmbResponseTypeDef:
         """
-        [Client.describe_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Client.describe_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         """
 
     def describe_task(self, TaskArn: str) -> DescribeTaskResponseTypeDef:
         """
-        [Client.describe_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Client.describe_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_task)
         """
 
     def describe_task_execution(
         self, TaskExecutionArn: str
     ) -> DescribeTaskExecutionResponseTypeDef:
         """
-        [Client.describe_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Client.describe_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         """
 
     def generate_presigned_url(
@@ -255,40 +282,45 @@ class DataSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         """
 
     def list_agents(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListAgentsResponseTypeDef:
         """
-        [Client.list_agents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Client.list_agents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.list_agents)
         """
 
     def list_locations(
-        self, MaxResults: int = None, NextToken: str = None
+        self,
+        MaxResults: int = None,
+        NextToken: str = None,
+        Filters: List[LocationFilterTypeDef] = None,
     ) -> ListLocationsResponseTypeDef:
         """
-        [Client.list_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Client.list_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.list_locations)
         """
 
     def list_tags_for_resource(
         self, ResourceArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         """
 
     def list_task_executions(
         self, TaskArn: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListTaskExecutionsResponseTypeDef:
         """
-        [Client.list_task_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Client.list_task_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.list_task_executions)
         """
 
-    def list_tasks(self, MaxResults: int = None, NextToken: str = None) -> ListTasksResponseTypeDef:
+    def list_tasks(
+        self, MaxResults: int = None, NextToken: str = None, Filters: List[TaskFilterTypeDef] = None
+    ) -> ListTasksResponseTypeDef:
         """
-        [Client.list_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Client.list_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.list_tasks)
         """
 
     def start_task_execution(
@@ -298,22 +330,22 @@ class DataSyncClient:
         Includes: List["FilterRuleTypeDef"] = None,
     ) -> StartTaskExecutionResponseTypeDef:
         """
-        [Client.start_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Client.start_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.start_task_execution)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagListEntryTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.untag_resource)
         """
 
     def update_agent(self, AgentArn: str, Name: str = None) -> Dict[str, Any]:
         """
-        [Client.update_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Client.update_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.update_agent)
         """
 
     def update_task(
@@ -326,19 +358,19 @@ class DataSyncClient:
         CloudWatchLogGroupArn: str = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Client.update_task)
+        [Client.update_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Client.update_task)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+        [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Paginator.ListAgents)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+        [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Paginator.ListLocations)
         """
 
     @overload
@@ -346,7 +378,7 @@ class DataSyncClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+        [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
         """
 
     @overload
@@ -354,13 +386,13 @@ class DataSyncClient:
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+        [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.27/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+        [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.47/reference/services/datasync.html#DataSync.Paginator.ListTasks)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
