@@ -44,6 +44,7 @@ __all__ = (
     "CreateLocationEfsResponseTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
     "CreateLocationNfsResponseTypeDef",
+    "CreateLocationObjectStorageResponseTypeDef",
     "CreateLocationS3ResponseTypeDef",
     "CreateLocationSmbResponseTypeDef",
     "CreateTaskResponseTypeDef",
@@ -51,6 +52,7 @@ __all__ = (
     "DescribeLocationEfsResponseTypeDef",
     "DescribeLocationFsxWindowsResponseTypeDef",
     "DescribeLocationNfsResponseTypeDef",
+    "DescribeLocationObjectStorageResponseTypeDef",
     "DescribeLocationS3ResponseTypeDef",
     "DescribeLocationSmbResponseTypeDef",
     "DescribeTaskExecutionResponseTypeDef",
@@ -60,8 +62,10 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "ListTaskExecutionsResponseTypeDef",
     "ListTasksResponseTypeDef",
+    "LocationFilterTypeDef",
     "PaginatorConfigTypeDef",
     "StartTaskExecutionResponseTypeDef",
+    "TaskFilterTypeDef",
 )
 
 AgentListEntryTypeDef = TypedDict(
@@ -103,6 +107,7 @@ OptionsTypeDef = TypedDict(
         "BytesPerSecond": int,
         "TaskQueueing": Literal["ENABLED", "DISABLED"],
         "LogLevel": Literal["OFF", "BASIC", "TRANSFER"],
+        "TransferMode": Literal["CHANGED", "ALL"],
     },
     total=False,
 )
@@ -187,6 +192,10 @@ CreateLocationNfsResponseTypeDef = TypedDict(
     "CreateLocationNfsResponseTypeDef", {"LocationArn": str}, total=False
 )
 
+CreateLocationObjectStorageResponseTypeDef = TypedDict(
+    "CreateLocationObjectStorageResponseTypeDef", {"LocationArn": str}, total=False
+)
+
 CreateLocationS3ResponseTypeDef = TypedDict(
     "CreateLocationS3ResponseTypeDef", {"LocationArn": str}, total=False
 )
@@ -247,6 +256,20 @@ DescribeLocationNfsResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeLocationObjectStorageResponseTypeDef = TypedDict(
+    "DescribeLocationObjectStorageResponseTypeDef",
+    {
+        "LocationArn": str,
+        "LocationUri": str,
+        "AccessKey": str,
+        "ServerPort": int,
+        "ServerProtocol": Literal["HTTPS", "HTTP"],
+        "AgentArns": List[str],
+        "CreationTime": datetime,
+    },
+    total=False,
+)
+
 DescribeLocationS3ResponseTypeDef = TypedDict(
     "DescribeLocationS3ResponseTypeDef",
     {
@@ -353,6 +376,26 @@ ListTasksResponseTypeDef = TypedDict(
     total=False,
 )
 
+LocationFilterTypeDef = TypedDict(
+    "LocationFilterTypeDef",
+    {
+        "Name": Literal["LocationUri", "LocationType", "CreationTime"],
+        "Values": List[str],
+        "Operator": Literal[
+            "Equals",
+            "NotEquals",
+            "In",
+            "LessThanOrEqual",
+            "LessThan",
+            "GreaterThanOrEqual",
+            "GreaterThan",
+            "Contains",
+            "NotContains",
+            "BeginsWith",
+        ],
+    },
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
@@ -360,3 +403,23 @@ PaginatorConfigTypeDef = TypedDict(
 StartTaskExecutionResponseTypeDef = TypedDict(
     "StartTaskExecutionResponseTypeDef", {"TaskExecutionArn": str}, total=False
 )
+
+TaskFilterTypeDef = TypedDict(
+    "TaskFilterTypeDef",
+    {
+        "Name": Literal["LocationId", "CreationTime"],
+        "Values": List[str],
+        "Operator": Literal[
+            "Equals",
+            "NotEquals",
+            "In",
+            "LessThanOrEqual",
+            "LessThan",
+            "GreaterThanOrEqual",
+            "GreaterThan",
+            "Contains",
+            "NotContains",
+            "BeginsWith",
+        ],
+    },
+)
